|
From: <sv...@va...> - 2016-10-11 17:01:50
|
Author: carll
Date: Tue Oct 11 18:01:42 2016
New Revision: 16037
Log:
Fix for missing ISA changes in HW cap stuff needs updating patch
A couple things got missed in the previous HW cap stuff needs updating patch
that cause the vbit tester to fail. The fixes are based on the patch
submitted by Mark Weilaard.
The changes were missed in Valgrind commit 16034
bugzilla 370265
Modified:
trunk/memcheck/tests/vbit-test/irops.c
trunk/tests/min_power_isa.c
Modified: trunk/memcheck/tests/vbit-test/irops.c
==============================================================================
--- trunk/tests/min_power_isa.c (original)
+++ trunk/tests/min_power_isa.c Tue Oct 11 18:01:42 2016
@@ -64,7 +64,7 @@
return !(isa_level >= 8);
} else {
- fprintf(stderr, "ERROR: invalid ISA version. Valid versions numbers are:\n" );
+ fprintf(stderr, "ERROR: invalid ISA version '%s'. Valid versions numbers are:\n", min_isa);
fprintf(stderr, " 2.05, 2.06, 2.07, 3.00\n" );
exit(2);
}
|
--- trunk/memcheck/tests/vbit-test/irops.c (original)
+++ trunk/memcheck/tests/vbit-test/irops.c Tue Oct 11 18:01:42 2016
@@ -1287,8 +1287,8 @@
case Iop_MulI128by10Carry:
case Iop_MulI128by10E:
case Iop_MulI128by10ECarry: {
- /* IROps require a processor that supports ISA 2.07 (Power 8) or newer */
- rc = system(MIN_POWER_ISA " 3.0 ");
+ /* IROps require a processor that supports ISA 3.00 (Power 9) or newer */
+ rc = system(MIN_POWER_ISA " 3.00 ");
rc /= 256;
/* MIN_POWER_ISA returns 0 if underlying HW supports the
* specified ISA or newer. Returns 1 if the HW does not support
Modified: trunk/tests/min_power_isa.c
==============================================================================